import axios from "axios";
import util from "@/libs/util";
import router from "@/router";
import Setting from "@/setting";
import { Message } from "element-ui";
const service = axios.create({
    baseURL: Setting.apiBaseURL,
    timeout: 10000000
});

// post请求头
service.defaults.headers.post['Content-Type'] = 'application/json;charset=UTF-8'
service.defaults.headers['X-Content-Type-Options'] = 'nosniff'
service.defaults.headers['Content-Security-Policy'] = 'script-src "self"; object-src "none";style-src cdn.example.org third-party.org; child-src https:'

// 请求拦截器
service.interceptors.request.use(config => {
    let token = util.local.get(Setting.tokenKey);
    if (token) config.headers.token = token;
    return config;
}, err => {
    util.errorMsg({
        message: "退出登陆",
        onClose: function() {
            router.push({ name: "/login" });
        }
    });
    return Promise.reject(err);
});

// 响应拦截器
service.interceptors.response.use(
    response => {
        const res = response.data;
        if (res.status == 200 || res.status == 10000 || res.status == 30001) {
            return Promise.resolve(res).catch(e => {});
        } else if (!res.status) {
            return Promise.resolve(res).catch(e => {});
        } else if (res.status === 10008) {
          Message.error({
            message: res.message,
            showClose: true,
            duration: 1500
          })
          return Promise.reject(res)
        } else {
            util.errorMsg(res.message);
            return Promise.reject(res)
        }
    },
    // 服务器状态码不是200的情况
    error => {
        if (error.response.status) {
            const { msg, code } = error.response.data
            switch (code) {
                // 401: 未登录
                case 401:
                    util.local.remove(Setting.storeKey);
                    util.local.remove(Setting.tokenKey);
                    util.errorMsg("登录过期，请重新登录");
                    setTimeout(() => {
                        router.replace({
                            path: "/login"
                        });
                    }, 1000);
                    break;
                // 403 token过期
                case 403:
                    util.local.remove(Setting.storeKey);
                    util.local.remove(Setting.tokenKey);
                    util.errorMsg("登录过期，请重新登录");
                    setTimeout(() => {
                        router.replace({
                            path: "/login"
                        });
                    }, 1000);
                    break;
                // 其他错误，直接抛出错误提示
                default:
                    util.errorMsg(msg);
                    Promise.reject(error.response.data);
            }
            return Promise.reject(error.response);
        }
    }
);

function get(url, params) {
    return new Promise((resolve, reject) => {
        service.get(url, { params: params }).then(res => {
            resolve(res);
        }).catch(err => {
            reject(err);
        });
    });
}

function post(url, params) {
    return new Promise((resolve, reject) => {
        service.post(url, params).then(res => {
            resolve(res);
        }).catch(err => {
            reject(err.data);
        });
    });
}

function del(url, params) {
    return new Promise((resolve, reject) => {
        service.delete(url, {
            params
        }).then(res => {
            resolve(res);
        }).catch(err => {
            reject(err.data);
        });
    });
}

function put(url, params) {
    return new Promise((resolve, reject) => {
        service.put(url, params).then(res => {
            resolve(res);
        }).catch(err => {
            reject(err.data);
        });
    });
}

export { get, post, del, put };